#include "clefB.xpm"
#include "clefT.xpm"
#include "clefB_icon.xpm"
#include "clefT_icon.xpm"
#include "sound_off.xpm"
#include "sound_on.xpm"
#include "next.xpm"
#include "empty.xpm"
#include "notationB.xpm"
#include "notationH.xpm"
#include "noteBLA.xpm"
#include "noteBLU.xpm"
#include "noteGRE.xpm"
#include "noteRED.xpm"
#include "noteBRO.xpm"
#include "level_0.xpm" 
#include "level_1.xpm"
#include "level_2.xpm"

#include "micOff.xpm"
#include "micOn.xpm"

#include "twolines.xpm"
